==> igniteui-webcomponents-core-4.0.2.tgz: package/esm2015/lib/WebPinColumnCancellableEventArgsDetailDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebCancelableEventArgsDetailDescriptionMetadata } from "./WebCancelableEventArgsDetailDescriptionMetadata";
import { WebPinColumnCancellableEventArgsDetailDescription } from "./WebPinColumnCancellableEventArgsDetailDescription";
/**
 * @hidden
 */
export let WebPinColumnCancellableEventArgsDetailDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebPinColumnCancellableEventArgsDetailDescriptionMetadata extends Base {
        static b(a) {
            if (WebPinColumnCancellableEventArgsDetailDescriptionMetadata.a == null) {
                WebPinColumnCancellableEventArgsDetailDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebPinColumnCancellableEventArgsDetailDescriptionMetadata.c(WebPinColumnCancellableEventArgsDetailDescriptionMetadata.a);
            }
            if (a.j(WebPinColumnCancellableEventArgsDetailDescriptionMetadata.a)) {
                return;
            }
            a.y(WebPinColumnCancellableEventArgsDetailDescriptionMetadata.a);
        }
        static c(a) {
            WebCancelableEventArgsDetailDescriptionMetadata.c(a);
            a.item("__qualifiedNameTS", "String:PinColumnCancellableEventArgsDetail");
            a.item("__packageNameWC", "String:grids");
            a.item("__isPlainObject", "Boolean");
        }
        static d(a) {
            WebPinColumnCancellableEventArgsDetailDescriptionMetadata.b(a);
            a.aa("WebPinColumnCancellableEventArgsDetail", () => new WebPinColumnCancellableEventArgsDetailDescription());
            a.z("WebPinColumnCancellableEventArgsDetail", WebPinColumnCancellableEventArgsDetailDescriptionMetadata.a);
        }
    }
    WebPinColumnCancellableEventArgsDetailDescriptionMetadata.$t = /*@__PURE__*/ markType(WebPinColumnCancellableEventArgsDetailDescriptionMetadata, 'WebPinColumnCancellableEventArgsDetailDescriptionMetadata');
    WebPinColumnCancellableEventArgsDetailDescriptionMetadata.a = null;
    return WebPinColumnCancellableEventArgsDetailDescriptionMetadata;
})();

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm2015/lib/WebPinColumnCancellableEventArgsDetailDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebCancelableEventArgsDetailDescriptionMetadata } from "./WebCancelableEventArgsDetailDescriptionMetadata";
import { WebPinColumnCancellableEventArgsDetailDescription } from "./WebPinColumnCancellableEventArgsDetailDescription";
/**
 * @hidden
 */
export let WebPinColumnCancellableEventArgsDetailDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebPinColumnCancellableEventArgsDetailDescriptionMetadata extends Base {
        static b(a) {
            if (WebPinColumnCancellableEventArgsDetailDescriptionMetadata.a == null) {
                WebPinColumnCancellableEventArgsDetailDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebPinColumnCancellableEventArgsDetailDescriptionMetadata.c(WebPinColumnCancellableEventArgsDetailDescriptionMetadata.a);
            }
            if (a.k(WebPinColumnCancellableEventArgsDetailDescriptionMetadata.a)) {
                return;
            }
            a.aa(WebPinColumnCancellableEventArgsDetailDescriptionMetadata.a);
        }
        static c(a) {
            WebCancelableEventArgsDetailDescriptionMetadata.c(a);
            a.item("__qualifiedNameTS", "String:PinColumnCancellableEventArgsDetail");
            a.item("__packageNameWC", "String:grids");
            a.item("__skipModuleRegisterWebComponents", "Boolean");
            a.item("__importOverrideWebComponents", "String:igniteui-webcomponents-grids/grids/combined");
            a.item("__importTypesWebComponents", "String:igniteui-webcomponents-grids/grids");
            a.item("__isPlainObject", "Boolean");
            a.item("__skipSuffix", "Boolean");
        }
        static d(a) {
            WebPinColumnCancellableEventArgsDetailDescriptionMetadata.b(a);
            a.ac("WebPinColumnCancellableEventArgsDetail", () => new WebPinColumnCancellableEventArgsDetailDescription());
            a.ab("WebPinColumnCancellableEventArgsDetail", WebPinColumnCancellableEventArgsDetailDescriptionMetadata.a);
        }
    }
    WebPinColumnCancellableEventArgsDetailDescriptionMetadata.$t = /*@__PURE__*/ markType(WebPinColumnCancellableEventArgsDetailDescriptionMetadata, 'WebPinColumnCancellableEventArgsDetailDescriptionMetadata');
    WebPinColumnCancellableEventArgsDetailDescriptionMetadata.a = null;
    return WebPinColumnCancellableEventArgsDetailDescriptionMetadata;
})();
